@@ -15,7 +15,8 @@ package_data = \
 {'': ['*']}
 
 install_requires = \
-['grpcio-tools>=1.24,<2.0',
+['cognite-geospatial-sdk>=0.1.8,<0.2.0',
+ 'grpcio-tools>=1.24,<2.0',
  'numpy>=1.17,<2.0',
  'protobuf>=3.12,<4.0',
  'python-dateutil>=2.8,<3.0',
@@ -27,7 +28,7 @@ extras_require = \
 
 setup_kwargs = {
     'name': 'cognite-seismic-sdk',
-    'version': '0.1.49',
+    'version': '0.1.51',
     'description': '',
     'long_description': None,
     'author': 'cognite',
