@@ -129,9 +129,9 @@ class Trace2DList(CustomList):
     def to_array(self):
         # TODO: remove sorting when server side sorting is done
         sorted_traces = sorted(self.to_list(), key=lambda x: (x.iline.value, x.xline.value))
-        return np.array([np.array(t.trace) for t in sorted_traces])
+        return np.array([np.array(t.trace) for t in sorted_traces if len(t.trace) > 0])
 
     def xy_array(self):
         # TODO: remove sorting when server side sorting is done
         sorted_traces = sorted(self.to_list(), key=lambda x: (x.iline.value, x.xline.value))
-        return np.array([np.array([t.get_x(), t.get_y()]) for t in sorted_traces])
+        return np.array([np.array([t.get_x(), t.get_y()]) for t in sorted_traces if len(t.trace) > 0])
